@@ -4,13 +4,12 @@ extern crate quickcheck;
 #[macro_use(quickcheck)]
 extern crate quickcheck_macros;
 
-use std::{convert::TryFrom, env, option::Option::None, time::Duration};
+use std::{convert::TryFrom, env, io::stdout, option::Option::None, time::Duration};
 
-use clap_generate::generators::{Bash, Elvish, Fish, PowerShell, Zsh};
 use git2::Repository;
-use miette::{GraphicalTheme, Result};
+use miette::Result;
 use mit_commit_message_lints::{
-    console::{style, style::print_completions},
+    console::{completion::print_completions, error_handling::miette_install, style},
     external::Git2,
     mit::{get_authors, set_commit_authors, Authors},
 };
@@ -21,33 +20,14 @@ mod cli;
 mod errors;
 
 fn main() -> Result<()> {
-    miette::set_panic_hook();
-    if env::var("DEBUG_PRETTY_ERRORS").is_ok() {
-        miette::set_hook(Box::new(|_| {
-            Box::new(
-                miette::MietteHandlerOpts::new()
-                    .force_graphical(true)
-                    .terminal_links(false)
-                    .graphical_theme(GraphicalTheme::unicode_nocolor())
-                    .build(),
-            )
-        }))
-        .unwrap();
-    }
+    miette_install();
 
     let mut app = cli::app::app();
     let args: cli::args::Args = app.clone().get_matches().into();
 
     // Simply print and exit if completion option is given.
     if let Some(completion) = args.completion() {
-        match completion {
-            "bash" => print_completions::<Bash>(&mut app),
-            "elvish" => print_completions::<Elvish>(&mut app),
-            "fish" => print_completions::<Fish>(&mut app),
-            "powershell" => print_completions::<PowerShell>(&mut app),
-            "zsh" => print_completions::<Zsh>(&mut app),
-            _ => println!("Unknown completion"), // Never reached
-        }
+        print_completions(&mut stdout(), &mut app, completion);
 
         std::process::exit(0);
     }
